.. _references:

References
==========

For more details and further information on continuous-variable quantum computation and Gaussian quantum information, please see :cite:`FR-weedbrook2012,FR-adesso2014,FR-serafini2017,FR-ferraro2005`.


.. bibliography:: references.bib
	:cited:
	:style: unsrt
